@@ -1004,9 +1004,18 @@ void SessionController::enableSearchBar(bool showSearchBar)
     if (showSearchBar) {
         connect(_searchBar, SIGNAL(searchChanged(QString)), this,
                 SLOT(searchTextChanged(QString)));
+        connect(_searchBar, SIGNAL(searchReturnPressed(QString)), this,
+                SLOT(searchTextChanged(QString)));
+        connect(_searchBar, SIGNAL(searchShiftPlusReturnPressed()), this,
+                SLOT(findPreviousInHistory()));
+        _searchBar->clearLineEdit();
     } else {
         disconnect(_searchBar, SIGNAL(searchChanged(QString)), this,
-                SLOT(searchTextChanged(QString)));
+                   SLOT(searchTextChanged(QString)));
+        disconnect(_searchBar, SIGNAL(searchReturnPressed(QString)), this,
+                   SLOT(searchTextChanged(QString)));
+        disconnect(_searchBar, SIGNAL(searchShiftPlusReturnPressed()), this,
+                   SLOT(findPreviousInHistory()));
     }
 }
 
@@ -1087,6 +1096,9 @@ void SessionController::beginSearch(const QString& text , int direction)
         task->addScreenWindow(_session , _view->screenWindow());
         task->execute();
     }
+    else if (text.isEmpty()) {
+        searchCompleted(false);
+    }
 
     _view->processFilters();
 }
