@@ -29,7 +29,7 @@
 #include <KCmdLineArgs>
 #include <KLocale>
 
-#define KONSOLE_VERSION "2.9"
+#define KONSOLE_VERSION "2.9.1"
 
 using Konsole::Application;
 
@@ -172,6 +172,9 @@ void fillCommandLineOptions(KCmdLineOptions& options)
     options.add("hide-menubar", ki18n("Hide the menubar, overriding the default setting"));
     options.add("show-tabbar", ki18n("Show the tabbar, overriding the default setting"));
     options.add("hide-tabbar", ki18n("Hide the tabbar, overriding the default setting"));
+    options.add("notransparency",
+                ki18n("Disable transparent backgrounds, even if the system"
+                      " supports them."));
     options.add("list-profiles", ki18n("List the available profiles"));
     options.add("list-profile-properties",
                 ki18n("List all the profile properties names and their type"
